<?php
namespace Zeedhi\DevOps\Model\Projectmanagement\Repositories;

use Doctrine\ORM\EntityRepository;
use Zeedhi\DevOps\Util\Utilities;

class DocumentTemplate extends EntityRepository {

    public function getDocumentTemplate($organizationId,$conditionsSQL,$limit, $offset) {

        $query = <<<SQL
        SELECT * FROM (
        SELECT DOC.ID,DOC.NAME,DOC.TYPE,ATT.LABEL,DOC.CREATED_AT,RES.NAME AS CREATED_BY,ATT.ID AS ATTACHMENT_ID
          FROM DOCUMENT_TEMPLATE DOC
          JOIN ATTACHMENT ATT ON (ATT.ID = DOC.ATTACHMENT)
		  JOIN RESOURCE_T RES ON (DOC.UPDATED_BY = RES.ID)
          WHERE DOC.ORGANIZATION_ID = :organizationId
			   )
			   WHERE 1 = 1
			    $conditionsSQL
SQL;
        $params = array(
            'organizationId' => $organizationId
        );

        $query = Utilities::getPaginatedQuery($query, $limit, $offset);
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getBasicBudgetDocumentData($issueId) {

        $query = <<<SQL
      SELECT ISS.ID,RES.NAME AS NAME_SPONSOR,BUD.ID AS BUDGET_ID,RES.DOCUMENT_NUMBER,RES.EMAIL,BUD.DISCOUNT_VALUE,BUD.DISCOUNT_PERCENT,
             TO_CHAR(SYSDATE,'DD/MM/YYYY') AS DTNOW,ISS.ID AS ISSUE_ID,ISS.NAME AS ISSUE_NAME,ISS.DESCRIPTION AS ISSUE_DESCRIPTION,
             (SELECT
                rtrim(xmlagg(xmlelement(e,REG.NAME ,',').extract('//text()') order by REG.NAME ).GetClobVal(),',')
                    FROM TASK ISS
                    JOIN RESOURCE_PROJECT GER ON (ISS.PROJECT = GER.PROJECT AND GER.TYPE = 'M' )
                    JOIN RESOURCE_T REG ON(REG.ID = GER.RESOURCE_C AND REG.STATUS = 'A')
                   WHERE ISS.ID = :issueId) AS MANAGER_NAME,
             ST.NAME AS STRUCTURE_NAME,
             TRIM(TO_CHAR((SUM(BIB.QUANTITY*BIB.ITEM_VALUE)+BUD.DISCOUNT_VALUE),'999G999G999G990D00', 'NLS_NUMERIC_CHARACTERS = '',.''')) AS TOTAL_VALUE,
             TRIM(TO_CHAR(SUM(BIB.QUANTITY*BIB.ITEM_VALUE),'999G999G999G990D00', 'NLS_NUMERIC_CHARACTERS = '',.''')) AS SUBTOTAL_VALUE

        FROM TASK ISS
   LEFT JOIN ALLOCATION ALO ON (ISS.ID = ALO.TASK AND ALO.TYPE = 'S')
   LEFT JOIN RESOURCE_T RES ON(RES.ID = ALO.RESOURCE_T)
   LEFT JOIN PROJECT P ON(P.ID = ISS.PROJECT)
   LEFT JOIN STRUCTURE ST ON(ST.ID = P.STRUCTURE)
        JOIN CLASSIFICATION_BUDGET_ITEM CBI ON (CBI.CLASSIFICATION = ISS.CLASSIFICATION )
        JOIN BUDGET_ITEM BUI ON (BUI.ID = CBI.BUDGET_ITEM)
        JOIN BUDGET BUD ON (BUD.TASK = ISS.ID)
        JOIN BUDGET_ITEM_BUDGET BIB ON (BIB.BUDGET = BUD.ID AND BIB.BUDGET_ITEM = BUI.ID)
       WHERE ISS.ID = :issueId
    GROUP BY ISS.ID, RES.NAME, BUD.ID, RES.DOCUMENT_NUMBER, RES.EMAIL,BUD.DISCOUNT_VALUE,BUD.DISCOUNT_PERCENT,ST.NAME,ISS.NAME,ISS.DESCRIPTION
SQL;
        $params = array(
            'issueId' => $issueId
        );

        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }
    public function getItemBudgetDocumentData($issueId) {

            $query = <<<SQL
          SELECT ROWNUM ,BIB.UNIT_MEASURE ,BIB.QUANTITY ,
                TRIM(TO_CHAR(BIB.ITEM_VALUE,'999G999G999G990D00', 'NLS_NUMERIC_CHARACTERS = '',.''')) AS ITEM_VALUE,
                TRIM(TO_CHAR(BIB.QUANTITY*BIB.ITEM_VALUE,'999G999G999G990D00', 'NLS_NUMERIC_CHARACTERS = '',.''')) AS TOTAL_VALUE_ITEM,
                BUI.NAME as ITEM_NAME,
                BUI.ID as COD

            FROM TASK ISS
            JOIN CLASSIFICATION_BUDGET_ITEM CBI ON (CBI.CLASSIFICATION = ISS.CLASSIFICATION )
            JOIN BUDGET_ITEM BUI ON (BUI.ID = CBI.BUDGET_ITEM)
            JOIN BUDGET BUD ON (BUD.TASK = ISS.ID)
            JOIN BUDGET_ITEM_BUDGET BIB ON (BIB.BUDGET = BUD.ID AND BIB.BUDGET_ITEM = BUI.ID)
           WHERE ISS.ID = :issueId
SQL;
            $params = array(
                'issueId' => $issueId
            );

            return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        }

public function findDocumentTRT($orgid, $filterString) {

            $query = <<<SQL
          SELECT ID, NAME, TYPE
           FROM DOCUMENT_TEMPLATE
           WHERE TYPE = 'C' AND ORGANIZATION_ID = :orgid $filterString
SQL;
            $params = array(
                'orgid' => $orgid
            );

            return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        }

}